"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidIBAN = void 0;
const validIBANSpecifications_1 = require("./validIBANSpecifications");
const NON_ALPHANUM = /[^a-zA-Z0-9]/g;
function electronicFormat(iban) {
    return iban.replace(NON_ALPHANUM, '').toUpperCase();
}
/**
 * Checks whether a given string is a valid International Bank Account Number (IBAN).
 * @param iban The IBAN to validate.
 * @returns `true` if the IBAN is valid, `false` otherwise.
 */
function isValidIBAN(iban) {
    if (typeof iban !== 'string') {
        return false;
    }
    const countryStructure = validIBANSpecifications_1.validIBANSpecifications.get(electronicFormat(iban).slice(0, 2));
    return !!countryStructure && countryStructure.isValidIBAN(iban);
}
exports.isValidIBAN = isValidIBAN;
//# sourceMappingURL=validateIBAN.js.map